@@ -14,6 +14,6 @@ echo '=== Changing into the "build" directory'
 cd build
 
 echo '=== Running "meson test"'
-meson test
+meson test -t 10
 
 echo '=== Seems fine!'
